@@ -8,7 +8,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.0.7');
+use version; our $VERSION = qv('0.0.8');
 
 {
 	my %id_of    : ATTR( );
@@ -53,7 +53,7 @@ use version; our $VERSION = qv('0.0.7');
 
 	sub submit_document { 
 		my ( $self, $arg_ref ) = @_; 
-		$arg_ref->{corpus_id} = $id_of{ident $self}; 
+		$arg_ref->{corpus_id} = $self->get_corpus_id();
 		return Text::Mining::Corpus::Document->new( $arg_ref ); 
 	}
 
@@ -301,117 +301,46 @@ __END__
 
 =head1 NAME
 
-Text::Mining::Corpus - Perl Tools for Text Mining
+Text::Mining::Corpus - Management and Analysis for Documents and Representations 
 
 
 =head1 VERSION
 
-This document describes Text::Mining::Corpus version 0.0.7
+This document describes Text::Mining::Corpus version 0.0.8
 
 
 =head1 SYNOPSIS
 
     use Text::Mining::Corpus;
 
-    my $wizard = CatalystX::Wizard->new({attribute => 'value'});
-
-    print $wizard->get_attribute(), "\n";
-
-    $wizard->set_attribute('new value');
-
-    print $wizard->get_attribute(), "\n";
-
-=for author to fill in:
-    Brief code example(s) here showing commonest usage(s).
-    This section will be as far as many users bother reading
-    so make it as educational and exeplary as possible.
-  
   
 =head1 DESCRIPTION
 
-=for author to fill in:
-    Write a full description of the module and its features here.
-    Use subsections (=head2, =head3) as appropriate.
-
 
 =head1 INTERFACE 
 
-=for author to fill in:
-    Write a separate section listing the public components of the modules
-    interface. These normally consist of either subroutines that may be
-    exported, or methods that may be called on objects belonging to the
-    classes provided by the module.
 
 
 =head1 DIAGNOSTICS
 
-=for author to fill in:
-    List every single error and warning message that the module can
-    generate (even the ones that will "never happen"), with a full
-    explanation of each problem, one or more likely causes, and any
-    suggested remedies.
-
-=over
-
-=item C<< Error message here, perhaps with %s placeholders >>
-
-[Description of error here]
-
-=item C<< Another error message here >>
-
-[Description of error here]
-
-[Et cetera, et cetera]
-
-=back
-
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-=for author to fill in:
-    A full explanation of any configuration system(s) used by the
-    module, including the names and locations of any configuration
-    files, and the meaning of any environment variables or properties
-    that can be set. These descriptions must also include details of any
-    configuration language used.
-  
 Text::Mining::Corpus requires no configuration files or environment variables.
 
 
 =head1 DEPENDENCIES
 
-=for author to fill in:
-    A list of all the other modules that this module relies upon,
-    including any restrictions on versions, and an indication whether
-    the module is part of the standard Perl distribution, part of the
-    module's distribution, or must be installed separately. ]
-
 None.
 
 
 =head1 INCOMPATIBILITIES
 
-=for author to fill in:
-    A list of any modules that this module cannot be used in conjunction
-    with. This may be due to name conflicts in the interface, or
-    competition for system or program resources, or due to internal
-    limitations of Perl (for example, many modules that use source code
-    filters are mutually incompatible).
-
 None reported.
 
 
 =head1 BUGS AND LIMITATIONS
 
-=for author to fill in:
-    A list of known problems with the module, together with some
-    indication Whether they are likely to be fixed in an upcoming
-    release. Also a list of restrictions on the features the module
-    does provide: data types that cannot be handled, performance issues
-    and the circumstances in which they may arise, practical
-    limitations on the size of data sets, special cases that are not
-    (yet) handled, etc.
-
 No bugs have been reported.
 
 Please report any bugs or feature requests to
@@ -419,14 +348,15 @@ C<bug-text-mining-corpus@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Roger A Hall  C<< <rogerhall@cpan.org> >>
+Michael Bauer  C<< <mbkodos@gmail.com> >>
 
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009, Roger A Hall C<< <rogerhall@cpan.org> >>. All rights reserved.
+Copyright (c) 2009, the Authors. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
